<?php

namespace domain\Product\Rotating;

use common\components\ActiveRecordCommon;
use domain\Producer\Producer\Producer;
use yii\db\ActiveQuery;

class Rotating extends ActiveRecordCommon
{
    public static function tableName()
    {
        return 'rotating';
    }

    public function rules()
    {
        return [
            [['id_producer', 'name', 'day'], 'required'],
            [['name'], 'string', 'max' => 255],
            [['id_producer', 'day', 'status'], 'integer'],
        ];
    }

    public function attributeLabels()
    {
        return [
            'id' => 'ID',
            'id_producer' => 'Producteur',
            'name' => 'Nom',
            'day' => 'Jour',
            'status' => 'Statut',
        ];
    }

    /* Getters / Setters */

    public function getId(): ?int
    {
        return $this->id;
    }

    public function getProducer(): Producer
    {
        return $this->producerRelation;
    }

    public function setProducer(Producer $producer): self
    {
        $this->populateFieldObject('id_producer', 'producerRelation', $producer);
        return $this;
    }

    public function getName(): string
    {
        return $this->name;
    }

    public function setName(string $name): self
    {
        $this->name = $name;
        return $this;
    }

    public function getDay(): int
    {
        return $this->day;
    }

    public function setDay(int $day): self
    {
        $this->day = $day;
        return $this;
    }

    public function getStatus(): int
    {
        return $this->status;
    }

    public function setStatus(int $status): self
    {
        $this->status = $status;
        return $this;
    }

    /* Relations */

    public function getProducerRelation(): ActiveQuery
    {
        return $this->hasOne(Producer::class, ['id' => 'id_producer']);
    }
}